==> zio-aws-ec2_2.12-5.17.125.1-sources.jar: zio/aws/ec2/model/Ipam.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, IpamScopeId, ResourceArn, IpamId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Ipam(
    ownerId: Option[String] = None,
    ipamId: Option[IpamId] = None,
    ipamArn: Option[ResourceArn] = None,
    ipamRegion: Option[String] = None,
    publicDefaultScopeId: Option[IpamScopeId] = None,
    privateDefaultScopeId: Option[IpamScopeId] = None,
    scopeCount: Option[Integer] = None,
    description: Option[String] = None,
    operatingRegions: Option[Iterable[zio.aws.ec2.model.IpamOperatingRegion]] =
      None,
    state: Option[zio.aws.ec2.model.IpamState] = None,
    tags: Option[Iterable[zio.aws.ec2.model.Tag]] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.ec2.model.Ipam = {
    import Ipam.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.Ipam
      .builder()
      .optionallyWith(ownerId.map(value => value: java.lang.String))(_.ownerId)
      .optionallyWith(
        ipamId.map(value => IpamId.unwrap(value): java.lang.String)
      )(_.ipamId)
      .optionallyWith(
        ipamArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.ipamArn)
      .optionallyWith(ipamRegion.map(value => value: java.lang.String))(
        _.ipamRegion
      )
      .optionallyWith(
        publicDefaultScopeId.map(value =>
          IpamScopeId.unwrap(value): java.lang.String
        )
      )(_.publicDefaultScopeId)
      .optionallyWith(
        privateDefaultScopeId.map(value =>
          IpamScopeId.unwrap(value): java.lang.String
        )
      )(_.privateDefaultScopeId)
      .optionallyWith(
        scopeCount.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.scopeCount)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        operatingRegions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.operatingRegions)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.Ipam.ReadOnly =
    zio.aws.ec2.model.Ipam.wrap(buildAwsValue())
}
object Ipam {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.Ipam] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.Ipam = zio.aws.ec2.model.Ipam(
      ownerId.map(value => value),
      ipamId.map(value => value),
      ipamArn.map(value => value),
      ipamRegion.map(value => value),
      publicDefaultScopeId.map(value => value),
      privateDefaultScopeId.map(value => value),
      scopeCount.map(value => value),
      description.map(value => value),
      operatingRegions.map(value =>
        value.map { item =>
          item.asEditable
        }
      ),
      state.map(value => value),
      tags.map(value =>
        value.map { item =>
          item.asEditable
        }
      )
    )
    def ownerId: Option[String]
    def ipamId: Option[IpamId]
    def ipamArn: Option[ResourceArn]
    def ipamRegion: Option[String]
    def publicDefaultScopeId: Option[IpamScopeId]
    def privateDefaultScopeId: Option[IpamScopeId]
    def scopeCount: Option[Integer]
    def description: Option[String]
    def operatingRegions
        : Option[List[zio.aws.ec2.model.IpamOperatingRegion.ReadOnly]]
    def state: Option[zio.aws.ec2.model.IpamState]
    def tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def getOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ownerId", ownerId)
    def getIpamId: ZIO[Any, AwsError, IpamId] =
      AwsError.unwrapOptionField("ipamId", ipamId)
    def getIpamArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("ipamArn", ipamArn)
    def getIpamRegion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipamRegion", ipamRegion)
    def getPublicDefaultScopeId: ZIO[Any, AwsError, IpamScopeId] =
      AwsError.unwrapOptionField("publicDefaultScopeId", publicDefaultScopeId)
    def getPrivateDefaultScopeId: ZIO[Any, AwsError, IpamScopeId] =
      AwsError.unwrapOptionField("privateDefaultScopeId", privateDefaultScopeId)
    def getScopeCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("scopeCount", scopeCount)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getOperatingRegions: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.IpamOperatingRegion.ReadOnly
    ]] = AwsError.unwrapOptionField("operatingRegions", operatingRegions)
    def getState: ZIO[Any, AwsError, zio.aws.ec2.model.IpamState] =
      AwsError.unwrapOptionField("state", state)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.Ipam
  ) extends zio.aws.ec2.model.Ipam.ReadOnly {
    override val ownerId: Option[String] =
      scala.Option(impl.ownerId()).map(value => value: String)
    override val ipamId: Option[IpamId] = scala
      .Option(impl.ipamId())
      .map(value => zio.aws.ec2.model.primitives.IpamId(value))
    override val ipamArn: Option[ResourceArn] = scala
      .Option(impl.ipamArn())
      .map(value => zio.aws.ec2.model.primitives.ResourceArn(value))
    override val ipamRegion: Option[String] =
      scala.Option(impl.ipamRegion()).map(value => value: String)
    override val publicDefaultScopeId: Option[IpamScopeId] = scala
      .Option(impl.publicDefaultScopeId())
      .map(value => zio.aws.ec2.model.primitives.IpamScopeId(value))
    override val privateDefaultScopeId: Option[IpamScopeId] = scala
      .Option(impl.privateDefaultScopeId())
      .map(value => zio.aws.ec2.model.primitives.IpamScopeId(value))
    override val scopeCount: Option[Integer] = scala
      .Option(impl.scopeCount())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val description: Option[String] =
      scala.Option(impl.description()).map(value => value: String)
    override val operatingRegions
        : Option[List[zio.aws.ec2.model.IpamOperatingRegion.ReadOnly]] = scala
      .Option(impl.operatingRegions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.IpamOperatingRegion.wrap(item)
        }.toList
      )
    override val state: Option[zio.aws.ec2.model.IpamState] = scala
      .Option(impl.state())
      .map(value => zio.aws.ec2.model.IpamState.wrap(value))
    override val tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.Ipam
  ): zio.aws.ec2.model.Ipam.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-5.17.130.5-sources.jar: zio/aws/ec2/model/Ipam.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, IpamScopeId, ResourceArn, IpamId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Ipam(
    ownerId: Option[String] = None,
    ipamId: Option[IpamId] = None,
    ipamArn: Option[ResourceArn] = None,
    ipamRegion: Option[String] = None,
    publicDefaultScopeId: Option[IpamScopeId] = None,
    privateDefaultScopeId: Option[IpamScopeId] = None,
    scopeCount: Option[Integer] = None,
    description: Option[String] = None,
    operatingRegions: Option[Iterable[zio.aws.ec2.model.IpamOperatingRegion]] =
      None,
    state: Option[zio.aws.ec2.model.IpamState] = None,
    tags: Option[Iterable[zio.aws.ec2.model.Tag]] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.ec2.model.Ipam = {
    import Ipam.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.Ipam
      .builder()
      .optionallyWith(ownerId.map(value => value: java.lang.String))(_.ownerId)
      .optionallyWith(
        ipamId.map(value => IpamId.unwrap(value): java.lang.String)
      )(_.ipamId)
      .optionallyWith(
        ipamArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.ipamArn)
      .optionallyWith(ipamRegion.map(value => value: java.lang.String))(
        _.ipamRegion
      )
      .optionallyWith(
        publicDefaultScopeId.map(value =>
          IpamScopeId.unwrap(value): java.lang.String
        )
      )(_.publicDefaultScopeId)
      .optionallyWith(
        privateDefaultScopeId.map(value =>
          IpamScopeId.unwrap(value): java.lang.String
        )
      )(_.privateDefaultScopeId)
      .optionallyWith(scopeCount.map(value => value: java.lang.Integer))(
        _.scopeCount
      )
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        operatingRegions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.operatingRegions)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.Ipam.ReadOnly =
    zio.aws.ec2.model.Ipam.wrap(buildAwsValue())
}
object Ipam {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.Ipam] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.Ipam = zio.aws.ec2.model.Ipam(
      ownerId.map(value => value),
      ipamId.map(value => value),
      ipamArn.map(value => value),
      ipamRegion.map(value => value),
      publicDefaultScopeId.map(value => value),
      privateDefaultScopeId.map(value => value),
      scopeCount.map(value => value),
      description.map(value => value),
      operatingRegions.map(value =>
        value.map { item =>
          item.asEditable
        }
      ),
      state.map(value => value),
      tags.map(value =>
        value.map { item =>
          item.asEditable
        }
      )
    )
    def ownerId: Option[String]
    def ipamId: Option[IpamId]
    def ipamArn: Option[ResourceArn]
    def ipamRegion: Option[String]
    def publicDefaultScopeId: Option[IpamScopeId]
    def privateDefaultScopeId: Option[IpamScopeId]
    def scopeCount: Option[Integer]
    def description: Option[String]
    def operatingRegions
        : Option[List[zio.aws.ec2.model.IpamOperatingRegion.ReadOnly]]
    def state: Option[zio.aws.ec2.model.IpamState]
    def tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def getOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ownerId", ownerId)
    def getIpamId: ZIO[Any, AwsError, IpamId] =
      AwsError.unwrapOptionField("ipamId", ipamId)
    def getIpamArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("ipamArn", ipamArn)
    def getIpamRegion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipamRegion", ipamRegion)
    def getPublicDefaultScopeId: ZIO[Any, AwsError, IpamScopeId] =
      AwsError.unwrapOptionField("publicDefaultScopeId", publicDefaultScopeId)
    def getPrivateDefaultScopeId: ZIO[Any, AwsError, IpamScopeId] =
      AwsError.unwrapOptionField("privateDefaultScopeId", privateDefaultScopeId)
    def getScopeCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("scopeCount", scopeCount)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getOperatingRegions: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.IpamOperatingRegion.ReadOnly
    ]] = AwsError.unwrapOptionField("operatingRegions", operatingRegions)
    def getState: ZIO[Any, AwsError, zio.aws.ec2.model.IpamState] =
      AwsError.unwrapOptionField("state", state)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.Ipam
  ) extends zio.aws.ec2.model.Ipam.ReadOnly {
    override val ownerId: Option[String] =
      scala.Option(impl.ownerId()).map(value => value: String)
    override val ipamId: Option[IpamId] = scala
      .Option(impl.ipamId())
      .map(value => zio.aws.ec2.model.primitives.IpamId(value))
    override val ipamArn: Option[ResourceArn] = scala
      .Option(impl.ipamArn())
      .map(value => zio.aws.ec2.model.primitives.ResourceArn(value))
    override val ipamRegion: Option[String] =
      scala.Option(impl.ipamRegion()).map(value => value: String)
    override val publicDefaultScopeId: Option[IpamScopeId] = scala
      .Option(impl.publicDefaultScopeId())
      .map(value => zio.aws.ec2.model.primitives.IpamScopeId(value))
    override val privateDefaultScopeId: Option[IpamScopeId] = scala
      .Option(impl.privateDefaultScopeId())
      .map(value => zio.aws.ec2.model.primitives.IpamScopeId(value))
    override val scopeCount: Option[Integer] =
      scala.Option(impl.scopeCount()).map(value => value: Integer)
    override val description: Option[String] =
      scala.Option(impl.description()).map(value => value: String)
    override val operatingRegions
        : Option[List[zio.aws.ec2.model.IpamOperatingRegion.ReadOnly]] = scala
      .Option(impl.operatingRegions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.IpamOperatingRegion.wrap(item)
        }.toList
      )
    override val state: Option[zio.aws.ec2.model.IpamState] = scala
      .Option(impl.state())
      .map(value => zio.aws.ec2.model.IpamState.wrap(value))
    override val tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.Ipam
  ): zio.aws.ec2.model.Ipam.ReadOnly = new Wrapper(impl)
}
